@@ -78,7 +78,7 @@ def automl(data, target_column, task):
         pipeline = automl.get_pipeline(i)
         pip["id"] = i
         pip["name"] = pipeline.name
-        pip["pipeline"] = pipeline
+        pip["pipeline"] = str(pipeline)
 
         pipeline.fit(X_train, y_train)
 
@@ -150,7 +150,7 @@ def automl(data, target_column, task):
     automl_result["Data Issue Messages"] = messages
     automl_result["Task"] = task
     automl_result["Pipelines"] = pipelines
-
+  
     automl_json = convert_to_json(automl_result)
     automl_json = automl_json.replace("\\", "")
     automl_json = automl_json.replace('"{"schema', '{"schema')
