@@ -8,6 +8,7 @@ class Deployment:
         with open("deployment.py", "w") as f:
             f.write("import requests")
             f.write("\nimport os")
+            f.write("\nimport pandas as pd")
             f.write("\nfrom pydantic import BaseModel")
             f.write("\nfrom huble import Experiment")
             f.write("\nfrom typing import Union")
@@ -27,7 +28,9 @@ class Deployment:
             f.write("\n")
             f.write("\n")
             f.write("\ndef predict(request_body: RequestBody):")
-            f.write("\n\treturn model.predict(request_body.dict())")
+            f.write("\n\trequest_body = request_body.dict()")
+            f.write("\n\tX = pd.DataFrame(request_body, index=[0])")
+            f.write("\n\treturn model.predict(X)")
 
 
 
