@@ -49,13 +49,16 @@ class Experiment:
             aws_secret_access_key="EyByFcqsBwTe4bWq6PwnoUJ9e2BqzShztJ48efVH",
         )
         bucket_name = "testsesaetsatast"
+        print("Created S3 client...")
         with open(file_name, "rb") as data:
             client.upload_fileobj(data, bucket_name, file_name)
         response = client.head_object(Bucket=bucket_name, Key=file_name)
         headers = response.get("ResponseMetadata", {}).get("HTTPHeaders", {})
         cid = headers.get("x-amz-meta-cid")
+        print("Uploading model...")
         requests.put(
             f"http://localhost:8000/experiments/model/{self.experiment_id}",
             data={"model": cid},
         )
+        print("Model uploaded successfully")
 
