@@ -92,49 +92,49 @@ def transpose(**params):
 # @function_error_handling("min_max_scale")
 def min_max_scale(**params):
     data = params["data"]
+    columns = params['columns']
     scaler = preprocessing.MinMaxScaler(**params["parameters"])
-    data[(params["column"])] = scaler.fit_transform(
-        data[(params["column"])].values.reshape(-1, 1)
-    )[:, 0]
+    for column in columns:
+        data[column] = scaler.fit_transform(data[[column]])    
     return data
 
 
 # @function_error_handling("max_abs_scale")
 def max_abs_scale(**params):
     data = params["data"]
+    columns = params['columns']
     scaler = preprocessing.MaxAbsScaler(**params["parameters"])
-    data[(params["column"])] = scaler.fit_transform(
-        data[(params["column"])].values.reshape(-1, 1)
-    )[:, 0]
+    for column in columns:
+        data[column] = scaler.fit_transform(data[[column]])    
     return data
 
 
 # @function_error_handling("robust_scale")
 def robust_scale(**params):
     data = params["data"]
+    columns = params['columns']
     scaler = preprocessing.RobustScaler(**params["parameters"])
-    data[(params["column"])] = scaler.fit_transform(
-        data[(params["column"])].values.reshape(-1, 1)
-    )[:, 0]
+    for column in columns:
+        data[column] = scaler.fit_transform(data[[column]])    
     return data
 
 
 # @function_error_handling("standard_scale")
 def standard_scale(**params):
     data = params["data"]
+    columns = params['columns']
     scaler = preprocessing.StandardScaler(**params["parameters"])
-    data[(params["column"])] = scaler.fit_transform(
-        data[(params["column"])].values.reshape(-1, 1)
-    )[:, 0]
+    for column in columns:
+        data[column] = scaler.fit_transform(data[[column]])    
     return data
 
 
 # @function_error_handling("normalize")
 def normalize(**params):
     data = params["data"]
-    for column in params["columns"]:
-        params["X"] = column
-        data = preprocessing.normalize(**params["parameters"])
+    columns=params['columns']
+    scaler  = preprocessing.Normalizer()
+    data[columns] = scaler.fit_transform(data[columns])
     return data
 
 
