@@ -1,6 +1,6 @@
-import lightgbm as lgb
-import xgboost as xgb
-import catboost as cb
+# import lightgbm as lgb
+# import xgboost as xgb
+# import catboost as cb
 from sklearn import (
     ensemble,
     linear_model,
@@ -70,14 +70,16 @@ def gradient_boosting(**params):
 
 # @function_error_handling("lgbm")
 def lgbm(**params):
-    model = lgb.LGBMClassifier(**params["parameters"])
-    return model
+    # model = lgb.LGBMClassifier(**params["parameters"])
+    # return model
+    pass
 
 
 # @function_error_handling("xgboost")
 def xgboost(**params):
-    model = xgb.XGBClassifier(**params["parameters"])
-    return model
+    # model = xgb.XGBClassifier(**params["parameters"])
+    # return model
+    pass
 
 
 # Regression
@@ -90,20 +92,22 @@ def linear_regression(**params):
 
 # @function_error_handling("lgbm_reg")
 def lgbm_reg(**params):
-    model = lgb.LGBMRegressor(**params["parameters"])
-    return model
-
+    # model = lgb.LGBMRegressor(**params["parameters"])
+    # return model
+    pass
 
 # @function_error_handling("xgboost_reg")
 def xgboost_reg(**params):
-    model = xgb.XGBRegressor(**params["parameters"])
-    return model
+    # model = xgb.XGBRegressor(**params["parameters"])
+    # return model
+    pass
 
 
 # @function_error_handling("catboost_reg")
 def catboost_reg(**params):
-    model = cb.CatBoostRegressor(**params["parameters"])
-    return model
+    # model = cb.CatBoostRegressor(**params["parameters"])
+    # return model
+    pass
 
 
 # @function_error_handling("st_gradient_descent_reg")
