@@ -1,6 +1,7 @@
 from .verify_ml import verify_ml_dataset
 from .recommend_model import recommend_model
 
-# from .automl import automl
 from .convert_to_reactflow_graph import convert_to_graph as get_reatflow_graph
 from .typed_params import get_typed_params
+
+from .inference_pipeline import inference_pip
\ No newline at end of file
